#[repr(u32)]
pub enum ZSTD_dParameter {
ZSTD_d_windowLogMax,
ZSTD_d_experimentalParam1,
ZSTD_d_experimentalParam2,
ZSTD_d_experimentalParam3,
ZSTD_d_experimentalParam4,
}Expand description
Advanced decompression API (Requires v1.4.0+)
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.