Enum zstd_sys::ZSTD_literalCompressionMode_e [−][src]
#[repr(u32)]
pub enum ZSTD_literalCompressionMode_e {
ZSTD_lcm_auto,
ZSTD_lcm_huffman,
ZSTD_lcm_uncompressed,
}Variants
< Automatically determine the compression mode based on the compression level. Negative compression levels will be uncompressed, and positive compression levels will be compressed.
< Always attempt Huffman compression. Uncompressed literals will still be emitted if Huffman compression is not profitable.
< Always emit uncompressed literals.