#[repr(u32)]
pub enum ZSTD_strategy {
ZSTD_fast,
ZSTD_dfast,
ZSTD_greedy,
ZSTD_lazy,
ZSTD_lazy2,
ZSTD_btlazy2,
ZSTD_btopt,
ZSTD_btultra,
ZSTD_btultra2,
}Expand description
Advanced compression API (Requires v1.4.0+)
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.