Function ZSTD_compress2

unsafe extern C { unwind: false } fn ZSTD_compress2(cctx: *mut ZSTD_CCtx, dst: *mut c_void, dstCapacity: usize, src: *const c_void, srcSize: usize) -> usize

ZSTD_compress2() : Behave the same as ZSTD_compressCCtx(), but compression parameters are set using the advanced API. (note that this entry point doesn't even expose a compression level parameter). ZSTD_compress2() always starts a new frame. Should cctx hold data from a previously unfinished frame, everything about it is forgotten.