Function ZSTD_compressCCtx

unsafe extern C { unwind: false } fn ZSTD_compressCCtx(cctx: *mut ZSTD_CCtx, dst: *mut c_void, dstCapacity: usize, src: *const c_void, srcSize: usize, compressionLevel: c_int) -> usize

ZSTD_compressCCtx() : Same as ZSTD_compress(), using an explicit ZSTD_CCtx. Important : in order to mirror ZSTD_compress() behavior, this function compresses at the requested compression level, ignoring any other advanced parameter . If any advanced parameter was set using the advanced API, they will all be reset. Only @compressionLevel remains.