Function ZSTD_getDecompressedSize

unsafe extern C { unwind: false } fn ZSTD_getDecompressedSize(src: *const c_void, srcSize: usize) -> c_ulonglong

ZSTD_getDecompressedSize() (obsolete): This function is now obsolete, in favor of ZSTD_getFrameContentSize(). Both functions work the same way, but ZSTD_getDecompressedSize() blends "empty", "unknown" and "error" results to the same return value (0), while ZSTD_getFrameContentSize() gives them separate return values. @return : decompressed size of src frame content if known and not empty, 0 otherwise.