Function ZSTD_getDictID_fromDDict

unsafe extern C { unwind: false } fn ZSTD_getDictID_fromDDict(ddict: *const ZSTD_DDict) -> c_uint

ZSTD_getDictID_fromDDict() : Requires v1.4.0+ Provides the dictID of the dictionary loaded into ddict. If @return == 0, the dictionary is not conformant to Zstandard specification, or empty. Non-conformant dictionaries can still be loaded, but as content-only dictionaries.