Struct zstd_sys::ZDICT_params_t
source · #[repr(C)]pub struct ZDICT_params_t {
pub compressionLevel: c_int,
pub notificationLevel: c_uint,
pub dictID: c_uint,
}Fields
compressionLevel: c_int< optimize for a specific zstd compression level; 0 means default
notificationLevel: c_uint< Write log to stderr; 0 = none (default); 1 = errors; 2 = progression; 3 = details; 4 = debug;
dictID: c_uint< force dictID value; 0 means auto mode (32-bits random value) NOTE: The zstd format reserves some dictionary IDs for future use. You may use them in private settings, but be warned that they may be used by zstd in a public dictionary registry in the future. These dictionary IDs are: - low range : <= 32767 - high range : >= (2^31)