Function ZSTD_cParam_getBounds

unsafe extern C { unwind: false } fn ZSTD_cParam_getBounds(cParam: ZSTD_cParameter) -> ZSTD_bounds

ZSTD_cParam_getBounds() : All parameters must belong to an interval with lower and upper bounds, otherwise they will either trigger an error or be automatically clamped. @return : a structure, ZSTD_bounds, which contains - an error status field, which must be tested using ZSTD_isError() - lower and upper bounds, both inclusive