Function ZSTD_getDictID_fromCDict
unsafe extern C { unwind: false } fn ZSTD_getDictID_fromCDict(cdict: *const ZSTD_CDict) -> c_uint
ZSTD_getDictID_fromCDict() : Requires v1.5.0+
Provides the dictID of the dictionary loaded into cdict.
If @return == 0, the dictionary is not conformant to Zstandard specification, or empty.
Non-conformant dictionaries can still be loaded, but as content-only dictionaries.