Function ZSTD_getDictID_fromFrame

unsafe extern C { unwind: false } fn ZSTD_getDictID_fromFrame(src: *const c_void, srcSize: usize) -> c_uint

ZSTD_getDictID_fromFrame() : Requires v1.4.0+ Provides the dictID required to decompressed the frame stored within src. If @return == 0, the dictID could not be decoded. This could for one of the following reasons :